@@ -55,13 +55,37 @@ class AmphoraLoadBalancerDriver(object):
         """
 
     @abc.abstractmethod
-    def start(self, loadbalancer, amphora):
+    def start(self, loadbalancer, amphora, timeout_dict=None):
         """Start the listeners on the amphora.
 
         :param loadbalancer: loadbalancer object to start listeners
         :type loadbalancer: octavia.db.models.LoadBalancer
         :param amphora: Amphora to start. If None, start on all amphora
         :type amphora: octavia.db.models.Amphora
+        :param timeout_dict: Dictionary of timeout values for calls to the
+                             amphora. May contain: req_conn_timeout,
+                             req_read_timeout, conn_max_retries,
+                             conn_retry_interval
+        :type timeout_dict: dict
+        :returns: return a value list (listener, vip, status flag--enable)
+
+        At this moment, we just build the basic structure for testing, will
+        add more function along with the development.
+        """
+
+    @abc.abstractmethod
+    def reload(self, loadbalancer, amphora, timeout_dict=None):
+        """Reload the listeners on the amphora.
+
+        :param loadbalancer: loadbalancer object to reload listeners
+        :type loadbalancer: octavia.db.models.LoadBalancer
+        :param amphora: Amphora to start. If None, reload on all amphora
+        :type amphora: octavia.db.models.Amphora
+        :param timeout_dict: Dictionary of timeout values for calls to the
+                             amphora. May contain: req_conn_timeout,
+                             req_read_timeout, conn_max_retries,
+                             conn_retry_interval
+        :type timeout_dict: dict
         :returns: return a value list (listener, vip, status flag--enable)
 
         At this moment, we just build the basic structure for testing, will
@@ -82,11 +106,13 @@ class AmphoraLoadBalancerDriver(object):
         """
 
     @abc.abstractmethod
-    def get_info(self, amphora):
+    def get_info(self, amphora, raise_retry_exception=False):
         """Returns information about the amphora.
 
         :param amphora: amphora object, need to use its id property
         :type amphora: octavia.db.models.Amphora
+        :param raise_retry_exception: Flag if outside task should be retried
+        :type boolean: False by default
         :returns: return a value list (amphora.id, status flag--'info')
 
         At this moment, we just build the basic structure for testing, will
@@ -197,6 +223,21 @@ class AmphoraLoadBalancerDriver(object):
         :type agent_config: string
         """
 
+    @abc.abstractmethod
+    def get_interface_from_ip(self, amphora, ip_address, timeout_dict=None):
+        """Get the interface name from an IP address.
+
+        :param amphora: The amphora to query.
+        :type amphora: octavia.db.models.Amphora
+        :param ip_address: The IP address to lookup. (IPv4 or IPv6)
+        :type ip_address: string
+        :param timeout_dict: Dictionary of timeout values for calls to the
+                             amphora. May contain: req_conn_timeout,
+                             req_read_timeout, conn_max_retries,
+                             conn_retry_interval
+        :type timeout_dict: dict
+        """
+
 
 @six.add_metaclass(abc.ABCMeta)
 class HealthMixin(object):
@@ -250,10 +291,17 @@ class VRRPDriverMixin(object):
     class XYZ: ...
     """
     @abc.abstractmethod
-    def update_vrrp_conf(self, loadbalancer):
+    def update_vrrp_conf(self, loadbalancer, amphorae_network_config, amphora,
+                         timeout_dict=None):
         """Update amphorae of the loadbalancer with a new VRRP configuration
 
         :param loadbalancer: loadbalancer object
+        :param amphorae_network_config: amphorae network configurations
+        :param amphora: The amphora object to update.
+        :param timeout_dict: Dictionary of timeout values for calls to the
+                             amphora. May contain: req_conn_timeout,
+                             req_read_timeout, conn_max_retries,
+                             conn_retry_interval
         """
 
     @abc.abstractmethod
@@ -264,10 +312,14 @@ class VRRPDriverMixin(object):
         """
 
     @abc.abstractmethod
-    def start_vrrp_service(self, loadbalancer):
-        """Start the VRRP services of all amphorae of the loadbalancer
+    def start_vrrp_service(self, amphora, timeout_dict=None):
+        """Start the VRRP services on the amphora
 
-        :param loadbalancer: loadbalancer object
+        :param amphora: The amphora object to start the service on.
+        :param timeout_dict: Dictionary of timeout values for calls to the
+                             amphora. May contain: req_conn_timeout,
+                             req_read_timeout, conn_max_retries,
+                             conn_retry_interval
         """
 
     @abc.abstractmethod
@@ -276,10 +328,3 @@ class VRRPDriverMixin(object):
 
         :param loadbalancer: loadbalancer object
         """
-
-    @abc.abstractmethod
-    def get_vrrp_interface(self, amphora):
-        """Get the VRRP interface object for a specific amphora
-
-        :param amphora: amphora object
-        """
