@@ -390,6 +390,11 @@ haproxy_amphora_opts = [
     cfg.IntOpt('api_db_commit_retry_max', default=5,
                help=_('The maximum amount of time to wait between retry '
                       'attempts.')),
+    cfg.IntOpt('default_connection_limit',
+               default=constants.HAPROXY_DEFAULT_MAXCONN,
+               help=_('Default connection_limit for listeners, used when '
+                      'setting "-1" or when unsetting connection_limit with '
+                      'the listener API.')),
 ]
 
 controller_worker_opts = [
@@ -600,7 +605,8 @@ nova_opts = [
                 help=_('Disable certificate validation on SSL connections')),
     cfg.BoolOpt('enable_anti_affinity', default=False,
                 help=_('Flag to indicate if nova anti-affinity feature is '
-                       'turned on.')),
+                       'turned on. This option is only used when creating '
+                       'amphorae in ACTIVE_STANDBY topology.')),
     cfg.StrOpt('anti_affinity_policy', default=constants.ANTI_AFFINITY,
                choices=[constants.ANTI_AFFINITY, constants.SOFT_ANTI_AFFINITY],
                help=_('Sets the anti-affinity policy for nova')),
