@@ -16,8 +16,7 @@ from oslo_config import cfg
 from oslo_log import log
 
 from octavia.common import config
-
-LOG = log.getLogger(__name__)
+from octavia.common import rpc
 
 
 def prepare_service(argv=None):
@@ -26,3 +25,4 @@ def prepare_service(argv=None):
     config.init(argv[1:])
     log.set_defaults()
     config.setup_logging(cfg.CONF)
+    rpc.init()
