@@ -27,9 +27,9 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
 from oslo_utils import uuidutils
-from sqlalchemy.orm import joinedload
 from sqlalchemy.orm import noload
 from sqlalchemy.orm import subqueryload
+from sqlalchemy.sql.expression import false
 from sqlalchemy.sql import func
 
 from octavia.common import constants as consts
@@ -1233,10 +1233,7 @@ class AmphoraRepository(BaseRepository):
                 .filter(models.Amphora.status != consts.DELETED)
                 # And the LB is also not DELETED
                 .filter(models.LoadBalancer.provisioning_status !=
-                        consts.DELETED)
-                # And what does this do? Some SQLAlchemy magic?
-                .options(joinedload('*'))
-            ).first()
+                        consts.DELETED)).first()
             if db_lb:
                 return db_lb.to_data_model()
             return None
@@ -1265,9 +1262,12 @@ class AmphoraRepository(BaseRepository):
             seconds=expired_seconds)
 
         with session.begin(subtransactions=True):
-            amp = session.query(self.model_class).with_for_update().filter_by(
-                cert_busy=False).filter(
-                self.model_class.cert_expiration < expired_date).first()
+            amp = session.query(self.model_class).with_for_update().filter(
+                self.model_class.status.notin_(
+                    [consts.DELETED, consts.PENDING_DELETE]),
+                self.model_class.cert_busy == false(),
+                self.model_class.cert_expiration < expired_date
+            ).first()
 
             if amp is None:
                 return None
