@@ -295,7 +295,7 @@ RET_LISTENER = {
     'protocol': 'HTTP',
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
     'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
                        '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
                        '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
@@ -315,7 +315,7 @@ RET_LISTENER_L7 = {
     'protocol': 'HTTP',
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
     'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
                        '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
                        '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
@@ -337,7 +337,7 @@ RET_LISTENER_TLS = {
     'protocol': 'TERMINATED_HTTPS',
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
     'tls_certificate_id': 'cont_id_1',
     'default_tls_path': '/etc/ssl/sample_loadbalancer_id_1/fakeCN.pem',
     'default_tls_container': RET_DEF_TLS_CONT,
@@ -352,7 +352,7 @@ RET_LISTENER_TLS_SNI = {
     'protocol': 'http',
     'protocol': 'TERMINATED_HTTPS',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
     'tls_certificate_id': 'cont_id_1',
     'default_tls_path': '/etc/ssl/sample_loadbalancer_id_1/fakeCN.pem',
     'default_tls_container': RET_DEF_TLS_CONT,
@@ -384,7 +384,7 @@ RET_LB = {
     'peer_port': 1024,
     'topology': 'SINGLE',
     'enabled': True,
-    'global_connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'global_connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
     'amphorae': [sample_amphora_tuple()]}
 
 RET_LB_L7 = {
@@ -395,7 +395,7 @@ RET_LB_L7 = {
     'peer_port': 1024,
     'topology': 'SINGLE',
     'enabled': True,
-    'global_connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'global_connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
     'amphorae': [sample_amphora_tuple()]}
 
 UDP_SOURCE_IP_BODY = {
@@ -590,7 +590,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           l7=False, enabled=True, insert_headers=None,
                           be_proto=None, monitor_ip_port=False,
                           monitor_proto=None, backup_member=False,
-                          disabled_member=False, connection_limit=-1,
+                          disabled_member=False,
+                          connection_limit=constants.DEFAULT_CONNECTION_LIMIT,
                           timeout_client_data=50000,
                           timeout_member_connect=5000,
                           timeout_member_data=50000,
@@ -599,7 +600,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           ssl_type_l7=False, pool_cert=False,
                           pool_ca_cert=False, pool_crl=False,
                           tls_enabled=False, hm_host_http_check=False,
-                          id='sample_listener_id_1', recursive_nest=False):
+                          id='sample_listener_id_1', recursive_nest=False,
+                          sample_default_pool=1,
+                          pool_enabled=True):
     proto = 'HTTP' if proto is None else proto
     if be_proto is None:
         be_proto = 'HTTP' if proto is 'TERMINATED_HTTPS' else proto
@@ -627,7 +630,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 pool_cert=pool_cert, pool_ca_cert=pool_ca_cert,
                 pool_crl=pool_crl, tls_enabled=tls_enabled,
                 hm_host_http_check=hm_host_http_check,
-                listener_id='sample_listener_id_1'),
+                listener_id='sample_listener_id_1',
+                enabled=pool_enabled),
             sample_pool_tuple(
                 proto=be_proto, monitor=monitor, persistence=persistence,
                 persistence_type=persistence_type,
@@ -636,7 +640,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 pool_cert=pool_cert, pool_ca_cert=pool_ca_cert,
                 pool_crl=pool_crl, tls_enabled=tls_enabled,
                 hm_host_http_check=hm_host_http_check,
-                listener_id='sample_listener_id_1')]
+                listener_id='sample_listener_id_1',
+                enabled=pool_enabled)]
         l7policies = [
             sample_l7policy_tuple('sample_l7policy_id_1', sample_policy=1),
             sample_l7policy_tuple('sample_l7policy_id_2', sample_policy=2),
@@ -659,7 +664,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 pool_cert=pool_cert, pool_ca_cert=pool_ca_cert,
                 pool_crl=pool_crl, tls_enabled=tls_enabled,
                 hm_host_http_check=hm_host_http_check,
-                listener_id='sample_listener_id_1')]
+                listener_id='sample_listener_id_1',
+                enabled=pool_enabled)]
         l7policies = []
     listener = in_listener(
         id=id,
@@ -682,7 +688,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
             pool_ca_cert=pool_ca_cert,
             pool_crl=pool_crl,
             tls_enabled=tls_enabled,
-            hm_host_http_check=hm_host_http_check
+            hm_host_http_check=hm_host_http_check,
+            sample_pool=sample_default_pool,
+            enabled=pool_enabled
         ) if alloc_default_pool else '',
         connection_limit=connection_limit,
         tls_certificate_id='cont_id_1' if tls else '',
@@ -763,7 +771,8 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                       has_http_reuse=True, pool_cert=False, pool_ca_cert=False,
                       pool_crl=False, tls_enabled=False,
                       hm_host_http_check=False,
-                      provisioning_status=constants.ACTIVE):
+                      provisioning_status=constants.ACTIVE,
+                      enabled=True):
     proto = 'HTTP' if proto is None else proto
     monitor_proto = proto if monitor_proto is None else monitor_proto
     in_pool = collections.namedtuple(
@@ -782,7 +791,13 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                   'persistence_cookie': persistence_cookie}
     persis = sample_session_persistence_tuple(**kwargs)
     mon = None
-    if sample_pool == 1:
+    if sample_pool == 0:
+        id = 'sample_pool_id_0'
+        members = []
+        if monitor is True:
+            mon = sample_health_monitor_tuple(
+                proto=monitor_proto, host_http_check=hm_host_http_check)
+    elif sample_pool == 1:
         id = 'sample_pool_id_1'
         members = [sample_member_tuple('sample_member_id_1', '10.0.0.99',
                                        monitor_ip_port=monitor_ip_port),
@@ -808,7 +823,7 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
         members=members,
         health_monitor=mon,
         session_persistence=persis if persistence is True else None,
-        enabled=True,
+        enabled=enabled,
         operating_status='ACTIVE', has_http_reuse=has_http_reuse,
         tls_certificate_id='pool_cont_1' if pool_cert else None,
         ca_tls_certificate_id='pool_ca_1' if pool_ca_cert else None,
@@ -1047,7 +1062,7 @@ def sample_base_expected_config(frontend=None, logging=None, backend=None,
                     "    default_backend sample_pool_id_1:sample_listener_id_1"
                     "\n"
                     "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN)
+            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
     if logging is None:
         logging = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
                    "%ci\\ %cp\\ %t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ "
@@ -1069,13 +1084,13 @@ def sample_base_expected_config(frontend=None, logging=None, backend=None,
                    "check inter 30s fall 3 rise 2 cookie sample_member_id_1\n"
                    "    server sample_member_id_2 10.0.0.98:82 weight 13 "
                    "check inter 30s fall 3 rise 2 cookie sample_member_id_2\n"
-                   "\n").format(maxconn=constants.HAPROXY_MAX_MAXCONN)
+                   "\n").format(maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
 
     if peers is None:
         peers = "\n\n"
     if global_opts is None:
         global_opts = "    maxconn {maxconn}\n\n".format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN)
+            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
     if defaults is None:
         defaults = ("defaults\n"
                     "    log global\n"
